# __Author__ = "Pranav Chandran"
# __Date__ = 28-02-2023
# __Time__ = 13:22
# __FileName__ = __init__.py
from .ssh_key_maker_bot import main

__all__ = ['main']
